@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import os, os.path
+import errno
 import gettext
 
 APP_DATA_DIR    = os.path.join('/usr/local', 'share') 
@@ -8,9 +9,11 @@ ICON_DIR        = os.path.join(APP_DATA_DIR, 'pixmaps')
 TEXTURE_DIR     = os.path.join(ICON_DIR, 'glchess')
 GLADE_DIR       = os.path.join(APP_DATA_DIR, 'glchess')
 BASE_DIR        = os.path.join(APP_DATA_DIR, 'glchess')
-LOCALEDIR 	= os.path.join(APP_DATA_DIR, 'locale')
+LOCALEDIR       = os.path.join(APP_DATA_DIR, 'locale')
 DATA_DIR        = os.path.expanduser('~/.gnome2/glchess/')
+LOG_DIR         = os.path.join(DATA_DIR, 'logs')
 CONFIG_FILE     = os.path.join(DATA_DIR, 'config.xml')
+AUTOSAVE_FILE   = os.path.join(DATA_DIR, 'autosave.pgn')
 LOCAL_AI_CONFIG = os.path.join(DATA_DIR, 'ai.xml')
 
 DOMAIN = 'gnome-games'
@@ -19,27 +22,19 @@ gettext.textdomain(DOMAIN)
 from gettext import gettext as _
 
 import gtk.glade
-gtk.glade.bindtextdomain (DOMAIN, LOCALEDIR)
-gtk.glade.textdomain (DOMAIN)
+gtk.glade.bindtextdomain(DOMAIN, LOCALEDIR)
+gtk.glade.textdomain(DOMAIN)
 
-VERSION = "2.18.1"
-APPNAME = _("glChess")
+VERSION   = "2.19.90.1"
+APPNAME   = _("glChess")
+ICON_NAME = 'gnome-glchess'
 
 COPYRIGHT     = _('Copyright 2005-2007 Robert Ancell (and contributors)')
-DESCRIPTION   = _('A 2D/3D chess interface for Gnome')
-WEBSITE       = 'http://glchess.sourceforge.net'
-WEBSITE_LABEL = _('glChess homepage')
+DESCRIPTION   = _('The 2D/3D chess game for GNOME. \n\nglChess is a part of GNOME Games.')
+WEBSITE       = 'http://www.gnome.org/projects/gnome-games/'
+WEBSITE_LABEL = _('GNOME Games web site')
 AUTHORS       = ['Robert Ancell <bob27@users.sourceforge.net>']
 ARTISTS       = ['John-Paul Gignac (3D Models)', 'Max Froumentin (2D Models)', 'Hylke Bons <h.bons@student.rug.nl> (icon)']
-TRANSLATORS   = [u"Luca Marturana <lucamarturana@gmail.com> (It)",
-                 u"Hakan Bekdas <hakanbekdas@yahoo.com> (tr)",
-                 u"A S Alam <apbrar@gmail.com> (pa)",
-                 u"Michał Bentkowski <mr.ecik@mail.com> (pl)",
-                 u"Daniel Nylander <po@danielnylander.se> (sv)",
-                 u"Zoraks <skatala4ever@gmail.com> (ca)",
-                 u"Elxan İsmayılov <elxan.i@gmail.com> (az)",
-                 u"Translators on Rosetta (launchpad.net)",
-                 u"Gnome Translation Team"]
 
 # The GPL license string will be translated, and the game name inserted.
 # This license is the same as in libgames-support/games-stock.c 
@@ -59,4 +54,8 @@ _("You should have received a copy of the GNU General Public License "
 #2D Models:
 #Copyright World Wide Web Consortium, (Massachusetts Institute of Technology, Institut National de Recherche en Informatique et en Automatique, Keio University). All Rights Reserved. http://www.w3.org/Consortium/Legal/"""
 
-if not os.path.exists(DATA_DIR): os.makedirs(DATA_DIR)
+try:
+    os.makedirs(DATA_DIR)
+except OSError, e:
+    if e.errno != errno.EEXIST:
+       print _('Unable to make data directory %(dir)s: %(error)s') % {'dir': DATA_DIR, 'error': e.strerror}
