@@ -21,6 +21,7 @@
 #include <gnome.h>
 
 #include "gnibbles.h"
+#include "main.h"
 #include "bonus.h"
 #include "boni.h"
 #include "ggz-network.h"
@@ -70,9 +71,11 @@ gnibbles_boni_add_bonus (GnibblesBoni * boni, gint t_x, gint t_y,
   gnibbles_bonus_draw (boni->bonuses[boni->numbonuses]);
   boni->numbonuses++;
   if (t_type != BONUSREGULAR)
-    gnibbles_play_sound ("appear");
+    games_sound_play ("appear");
 #ifdef GGZ_CLIENT
-  network_add_bonus (t_x, t_y, t_type, t_fake, t_countdown);
+  if (ggz_network_mode) { 
+    network_add_bonus (t_x, t_y, t_type, t_fake, t_countdown);
+  }
 #endif
 
 }
@@ -93,7 +96,7 @@ gnibbles_boni_add_bonus_final (GnibblesBoni * boni, gint t_x, gint t_y,
   gnibbles_bonus_draw (boni->bonuses[boni->numbonuses]);
   boni->numbonuses++;
   if (t_type != BONUSREGULAR)
-    gnibbles_play_sound ("appear");
+    games_sound_play ("appear");
 }
 
 int
@@ -121,7 +124,9 @@ gnibbles_boni_remove_bonus (GnibblesBoni * boni, gint x, gint y)
   int i;
 
 #ifdef GGZ_CLIENT
-  network_remove_bonus (x, y);
+  if (ggz_network_mode) { 
+    network_remove_bonus (x, y);
+  }
 #endif
   for (i = 0; i < boni->numbonuses; i++) {
     if ((x == boni->bonuses[i]->x &&
